#!/usr/bin/env python3

import os.path

import numpy
import numpy as np
import sys
try:
    import matplotlib.pyplot as plt
except ImportError:
    print("Module matplotlib required. Please install with pip install matplotlib", file=sys.stderr)
    exit(-1)

def parse(path, step):
    table = list()
    units = {"m": 1, "g": 2, "t": 3}
    with open(path) as file:
        for line in file:
            fields = line.strip().replace(',', '.').split(" ")
            for i in range(len(fields)):
                if fields[i][-1] in units.keys():
                    fields[i] = float(fields[i][:-1]) * 1000 ** units[fields[i][-1]]
                else:
                    fields[i] = float(fields[i])

            table.append(np.array(fields))

    if step > 1:
        table2 = list()
        table2.append(table[0])
        for i in range(1, len(table), step):
            nrow = table[i]
            for j in range(1, step):
                if i + j == len(table):
                    break
                nrow += table[i + j]
            nrow /= j + 1
            table2.append(nrow)
        table = table2

    t = np.arange(0, len(table), 1)
    men = (np.array([f[1] for f in table]) + np.array([f[2] for f in table])) / 1000000
    cpu = np.array([f[-1] for f in table]) / 100

    fig, ax1 = plt.subplots()
    title = f"{os.path.splitext(os.path.basename(path))[0]}\n" \
            f"Avg CPU: {round(numpy.average(cpu), 2)}      Max CPU: {round(max(cpu), 2)}\n" \
            f"Max Memory: {round(max(men), 2)} (GB)"
    plt.title(title)

    color = 'tab:blue'
    ax1.set_xlabel('')
    ax1.set_ylabel('CPU', color=color)
    ax1.plot(t, cpu, color=color)
    ax1.tick_params(axis='y', labelcolor=color)

    ax2 = ax1.twinx()

    color = 'tab:red'
    ax2.set_ylabel('Memory (GB)', color=color)
    ax2.plot(t, men, color=color)
    ax2.tick_params(axis='y', labelcolor=color)

    fig.tight_layout()
    plt.savefig(path + "." + str(step) + ".png")


def main():
    if len(sys.argv) < 2:
        print("use <file|folder> [step]")
        exit(-1)

    path = sys.argv[1]
    if len(sys.argv) > 2:
        step = int(sys.argv[2])
    else:
        step = 1

    if os.path.isfile(path):
        parse(path, step)
    else:
        for file in os.listdir(path):
            if file.endswith(".prof"):
                try:
                    parse(os.path.join(path, file), step)
                except:
                    pass


if __name__ == '__main__':
    main()



#!/usr/bin/env python3

import sys
import os


def show(name, secs, out):
    d = int(secs / 3600 / 24)
    h = int(secs / 3600) % 24
    m = int(secs / 60) % 60
    s = round(secs % 60, 2)

    row = name + ": "
    if d > 0:
        row += str(d) + " days, "
    if h > 0:
        row += str(h) + " hours, "
    if m > 0:
        row += str(m) + " minutes, "
    row += str(s) + " seconds"
    print(row, file=out)


def parse(file, short):
    total = float(0)
    table = []
    row_check = False
    relative = False
    last_secs = 0

    with open(file) as finput, open(file + '.sum', 'w') as out:
        for line in finput:
            if "seconds" in line and line.strip()[0].isdigit():
                secs_s, name = line.split("seconds")[0:2]
                name = name[1:].strip()
                secs = float(secs_s)
                if not relative:
                    secs, last_secs = secs - last_secs, secs
                total += secs
                if len(table) == 0:
                    row_check = True
                    table.append((name, secs))
                else:
                    rname = table[-1][0]
                    rsecs = table[-1][1]

                    if short and "Tree partitioned" in name:
                        table[-1] = (rname, rsecs + secs)
                        row_check = True
                        continue

                    if row_check:
                        for i in range(min(len(rname), len(name))):
                            if rname[i] != name[i]:
                                break

                        if i > 0 and "," in name and not short:
                            i = name.index(',') + 1

                        if i > 2 and name[i - 2] == ' ' and short:
                            i -= 1

                        if i > 4 and (name[i - 1] == ' ' or name[i - 1] == ','):
                            table[-1] = (rname[:i].strip(), rsecs + secs)
                            row_check = short
                            continue

                    if len(rname) <= len(name) and rname == name[:len(rname)]:
                        table[-1] = (rname, rsecs + secs)
                    else:
                        row_check = True
                        table.append((name.split(",")[0], secs))
            elif len(table) == 0:
                relative = relative or "-relative-progress" in line
                print(line.strip(), file=out)

        tab = 0
        for name, secs in table:
            if len(name) > tab:
                tab = len(name)

        for name, secs in table:
            show(" " * (tab - len(name)) + name, secs, out)
        show(" " * (tab - len("Total")) + "Total", total, out)


def main():
    if len(sys.argv) < 2:
        print("use <file|folder> [-s]\n  -s: shorter summary")
        exit(-1)

    path = sys.argv[1]
    short = len(sys.argv) > 2 and "-s" == sys.argv[2]

    if os.path.isfile(path):
        parse(path, short)
    else:
        for file in os.listdir(path):
            if file.endswith(".out"):
                try:
                    parse(os.path.join(path, file), short)
                except:
                    pass


if __name__ == '__main__':
    main()



import os
import subprocess
import shutil
import sys

binary = " VeryFastTree"

binaries = {
    "OpenMP": [],
    "OpenMP-AVX2": ["-DUSE_AVX2=ON"],
    "OpenMP-AVX512": ["-DUSE_AVX512=ON"],
}


def main():
    version = sys.argv[1]
    for name, options in binaries.items():
        shutil.rmtree("win-build", ignore_errors=True)
        shutil.copytree(os.path.dirname(os.path.dirname(os.path.abspath(__file__))), "win-build")
        os.chdir("win-build")
        subprocess.call(["cmake", "."] + options)
        subprocess.call(["cmake", "--build", "."])
        os.chdir("..")
        os.mkdir("win-build/release")
        for file in os.listdir("win-build/Debug/"):
            if file.endswith(".exe"):
                shutil.copy("win-build/Debug/" + file, "win-build/release/")
        shutil.copy("README.md", "win-build/release")
        shutil.copy("LICENSE", "win-build/release")
        shutil.make_archive(binary + version + "Win64-" + name, 'zip', "win-build/release")
        shutil.rmtree("win-build", ignore_errors=True)


if __name__ == "__main__":
    if len(sys.argv) < 2:
        print("version required")
        exit(-1)
    main()



#!/usr/bin/env python3
import sys
try:
	from ete3 import Tree
except ImportError:
	print("Module ete3 required. Please install with pip install ete3", file=sys.stderr)
	exit(-1)


def main():
	if len(sys.argv) <= 2:
		exit("use " + sys.argv[0] + " tree1 tree2")

	try:
		tree1 = Tree(sys.argv[1])
		tree2 = Tree(sys.argv[2])

		rf, max_parts = tree1.robinson_foulds(tree2, unrooted_trees=True)[:2]
		accuracy = round((1 - (rf / max_parts)) * 100, 2)
		print("Accuracy: %.2f%%" % accuracy)

	except Exception as e:
		print(str(e), file=sys.stderr)

if __name__ == "__main__":
	main()
